============
Installation
============

At the command line::

    $ easy_install openupgradelib

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv openupgradelib
    $ pip install openupgradelib
